/*---------------------------------------------------------------------------------------------
 *  Copyright (c) Microsoft Corporation. All rights reserved.
 *  Licensed under the MIT License. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Descriptor = /** @class */ (function () {
    function Descriptor(ctor) {
        var staticArguments = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            staticArguments[_i - 1] = arguments[_i];
        }
        this._ctor = ctor;
        this._staticArguments = staticArguments;
    }
    Descriptor.prototype.appendStaticArguments = function (more) {
        this._staticArguments.push.apply(this._staticArguments, more);
    };
    Descriptor.prototype.staticArguments = function (nth) {
        if (isNaN(nth)) {
            return this._staticArguments.slice(0);
        }
        else {
            return this._staticArguments[nth];
        }
    };
    Object.defineProperty(Descriptor.prototype, "ctor", {
        get: function () {
            return this._ctor;
        },
        enumerable: true,
        configurable: true
    });
    Descriptor.prototype.bind = function () {
        var moreStaticArguments = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            moreStaticArguments[_i] = arguments[_i];
        }
        var allArgs = [];
        allArgs = allArgs.concat(this.staticArguments());
        allArgs = allArgs.concat(moreStaticArguments);
        return new (Descriptor.bind.apply(Descriptor, [void 0, this._ctor].concat(allArgs)))();
    };
    Descriptor.prototype._validate = function (type) {
        if (!type) {
            throw new Error("can not be falsy");
        }
    };
    return Descriptor;
}());
exports.Descriptor = Descriptor;
exports.createDescriptor = function (ctor) {
    var staticArguments = [];
    for (var _i = 1; _i < arguments.length; _i++) {
        staticArguments[_i - 1] = arguments[_i];
    }
    return new (Descriptor.bind.apply(Descriptor, [void 0, ctor].concat(staticArguments)))();
};
